@@ -16,13 +16,17 @@
 
 module Data.Functor.Contravariant.Adjunction
   ( Adjunction(..)
+  , adjuncted
   , contrarepAdjunction
   , coindexAdjunction
   ) where
 
+#if defined(__GLASGOW_HASKELL__) && __GLASGOW_HASKELL__ < 707
 import Control.Monad.Instances ()
+#endif
 import Data.Functor.Contravariant
-import Data.Functor.Contravariant.Representable
+import Data.Functor.Contravariant.Rep
+import Data.Profunctor
 
 -- | An adjunction from @Hask^op@ to @Hask@
 --
@@ -47,6 +51,16 @@ class (Contravariant f, Representable g) => Adjunction f g | f -> g, g -> f wher
   leftAdjunct f = contramap f . unit
   rightAdjunct f = contramap f . counit
 
+-- | 'leftAdjunct' and 'rightAdjunct' form two halves of an isomorphism.
+--
+-- This can be used with the combinators from the @lens@ package.
+--
+-- @'adjuncted' :: 'Adjunction' f g => 'Iso'' (b -> f a) (a -> g b)@
+adjuncted :: (Adjunction f g, Profunctor p, Functor h) 
+          => p (a -> g b) (h (c -> g d)) -> p (b -> f a) (h (d -> f c))
+adjuncted = dimap leftAdjunct (fmap rightAdjunct)
+{-# INLINE adjuncted #-}
+
 -- | This 'Adjunction' gives rise to the @Cont@ 'Monad'
 instance Adjunction (Op r) (Op r) where
   unit a = Op (\k -> getOp k a)
